@@ -44,11 +44,11 @@ nitmon=to.integer(nitmon),
 nit=to.integer(nit),
 beta=to.single(beta),
 reff=to.single(reff),
-a=to.double(a),
-sa=to.double(sa),
-su1=to.double(su1),
-sa0=to.double(sa0),
-sd=to.double(sd),
+a=as.double(a),
+sa=as.double(sa),
+su1=as.double(su1),
+sa0=as.double(sa0),
+sd=as.double(sd),
 ss=to.single(ss),
 wgt=to.single(wgt),
 dl=to.single(dl),
