@@ -2,7 +2,7 @@
 function(x) {
 if (missing(x)) messagena("x")
 f <- single(1)
-f.res <- .Fortran("cerf",
+f.res <- .Fortran("cerfz",
 x=to.single(x),
 f=to.single(f))
 list(f=f.res$f)
