@@ -1,7 +1,7 @@
 "libet0" <-
 function() {
 bt0 <- single(1)
-f.res <- .Fortran("libet0",
+f.res <- .Fortran("libet0z",
 bt0=to.single(bt0))
 list(bt0=f.res$bt0)
 }
