@@ -20,7 +20,7 @@ st <- double(ncov)
 st1 <- double(ncov)
 f.res <- .Fortran("int55",
 x=to.single(x),
-a=to.double(a),
+a=as.double(a),
 as.integer(exu()),
 as.integer(exup()),
 nobs=to.integer(nobs),
@@ -35,14 +35,14 @@ tol=to.single(tol),
 xfud=to.single(xfud),
 nit=to.integer(nit),
 dist=to.single(dist),
-sa=to.double(sa),
-ss=to.double(ss),
+sa=as.double(sa),
+ss=as.double(ss),
 sz=to.single(sz),
-su=to.double(su),
-sup=to.double(sup),
-sy1=to.double(sy1),
-sy2=to.double(sy2),
-st=to.double(st),
-st1=to.double(st1))
+su=as.double(su),
+sup=as.double(sup),
+sy1=as.double(sy1),
+sy2=as.double(sy2),
+st=as.double(st),
+st1=as.double(st1))
 list(a=f.res$a,nit=f.res$nit,dist=f.res$dist,su=f.res$su)
 }
